==> jc-1.4.0.tar.gz: java/rmi/server/RemoteStub.h <==
// public abstract class java.rmi.server.RemoteStub

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 46051fa019dc720f java_rmi_server_RemoteObject
// @dep_class b0c4f5e03c482057 java_rmi_server_RemoteStub

// header file dependencies
// @dep_header java_rmi_server_RemoteObject

#include "java/rmi/server/RemoteObject.h"

#ifndef _JC_java_rmi_server_RemoteStub_H_
#define _JC_java_rmi_server_RemoteStub_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_server_RemoteRef$object;
struct _jc_java_rmi_server_RemoteStub$object;

// Typedefs
typedef struct _jc_java_rmi_server_RemoteStub$sub_refs	_jc_java_rmi_server_RemoteStub$sub_refs;
typedef struct _jc_java_rmi_server_RemoteStub$sub_nonrefs	_jc_java_rmi_server_RemoteStub$sub_nonrefs;
typedef struct _jc_java_rmi_server_RemoteStub$refs	_jc_java_rmi_server_RemoteStub$refs;
typedef struct _jc_java_rmi_server_RemoteStub$nonrefs	_jc_java_rmi_server_RemoteStub$nonrefs;
typedef struct _jc_java_rmi_server_RemoteStub$object	_jc_java_rmi_server_RemoteStub$object;

typedef struct _jc_java_rmi_server_RemoteStub$fields_struct	_jc_java_rmi_server_RemoteStub$fields_struct;
typedef const struct _jc_java_rmi_server_RemoteStub$vmethods	_jc_java_rmi_server_RemoteStub$vmethods;
typedef const struct _jc_java_rmi_server_RemoteStub$vtable	_jc_java_rmi_server_RemoteStub$vtable;
typedef const struct _jc_java_rmi_server_RemoteStub$vtype	_jc_java_rmi_server_RemoteStub$vtype;

// Class fields structure
struct _jc_java_rmi_server_RemoteStub$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_RemoteStub$fields_struct _jc_java_rmi_server_RemoteStub$class_fields;

// Constructors
extern void _jc_java_rmi_server_RemoteStub$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RemoteStub$object *);
extern void _jc_java_rmi_server_RemoteStub$method$_init$bebac18f06a4adf7(_jc_env *, struct _jc_java_rmi_server_RemoteStub$object *, struct _jc_object *);

// Static methods
extern void _jc_java_rmi_server_RemoteStub$method$setRef$dab5ee41be62ebd3(_jc_env *, struct _jc_java_rmi_server_RemoteStub$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_java_rmi_server_RemoteStub$vmethods {
};

// Vtable
struct _jc_java_rmi_server_RemoteStub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteStub$vmethods	java_rmi_server_RemoteStub;
};

// Vtype
struct _jc_java_rmi_server_RemoteStub$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RemoteStub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RemoteStub$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RemoteStub$refs {
    _jc_java_rmi_server_RemoteStub$sub_refs	java_rmi_server_RemoteStub;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RemoteStub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RemoteStub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteStub$sub_nonrefs	java_rmi_server_RemoteStub;
};

// Object instance structure
struct _jc_java_rmi_server_RemoteStub$object {
	_jc_java_rmi_server_RemoteStub$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RemoteStub$vtype	*vtype;
	_jc_java_rmi_server_RemoteStub$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RemoteStub$vtype _jc_java_rmi_server_RemoteStub$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RemoteStub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RemoteStub$class_object;

#endif	/* _JC_java_rmi_server_RemoteStub_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/RemoteStub.h <==
// public abstract class java.rmi.server.RemoteStub

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8c9f90d92f098cf3 java_rmi_server_RemoteObject
// @dep_class b0c4f5e03c482057 java_rmi_server_RemoteStub

// header file dependencies
// @dep_header java_rmi_server_RemoteObject

#include "java/rmi/server/RemoteObject.h"

#ifndef _JC_java_rmi_server_RemoteStub_H_
#define _JC_java_rmi_server_RemoteStub_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_server_RemoteRef$object;
struct _jc_java_rmi_server_RemoteStub$object;

// Typedefs
typedef struct _jc_java_rmi_server_RemoteStub$sub_refs	_jc_java_rmi_server_RemoteStub$sub_refs;
typedef struct _jc_java_rmi_server_RemoteStub$sub_nonrefs	_jc_java_rmi_server_RemoteStub$sub_nonrefs;
typedef struct _jc_java_rmi_server_RemoteStub$refs	_jc_java_rmi_server_RemoteStub$refs;
typedef struct _jc_java_rmi_server_RemoteStub$nonrefs	_jc_java_rmi_server_RemoteStub$nonrefs;
typedef struct _jc_java_rmi_server_RemoteStub$object	_jc_java_rmi_server_RemoteStub$object;

typedef struct _jc_java_rmi_server_RemoteStub$fields_struct	_jc_java_rmi_server_RemoteStub$fields_struct;
typedef const struct _jc_java_rmi_server_RemoteStub$vmethods	_jc_java_rmi_server_RemoteStub$vmethods;
typedef const struct _jc_java_rmi_server_RemoteStub$vtable	_jc_java_rmi_server_RemoteStub$vtable;
typedef const struct _jc_java_rmi_server_RemoteStub$vtype	_jc_java_rmi_server_RemoteStub$vtype;

// Class fields structure
struct _jc_java_rmi_server_RemoteStub$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_RemoteStub$fields_struct _jc_java_rmi_server_RemoteStub$class_fields;

// Constructors
extern void _jc_java_rmi_server_RemoteStub$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RemoteStub$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_RemoteStub$method$_init$bebac18f06a4adf7(_jc_env *, struct _jc_java_rmi_server_RemoteStub$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_rmi_server_RemoteStub$method$setRef$dab5ee41be62ebd3(_jc_env *, struct _jc_java_rmi_server_RemoteStub$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_RemoteStub$vmethods {
};

// Vtable
struct _jc_java_rmi_server_RemoteStub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteStub$vmethods	java_rmi_server_RemoteStub;
};

// Vtype
struct _jc_java_rmi_server_RemoteStub$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RemoteStub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RemoteStub$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RemoteStub$refs {
    _jc_java_rmi_server_RemoteStub$sub_refs	java_rmi_server_RemoteStub;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RemoteStub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RemoteStub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteStub$sub_nonrefs	java_rmi_server_RemoteStub;
};

// Object instance structure
struct _jc_java_rmi_server_RemoteStub$object {
	_jc_java_rmi_server_RemoteStub$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RemoteStub$vtype	*vtype;
	_jc_java_rmi_server_RemoteStub$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RemoteStub$vtype _jc_java_rmi_server_RemoteStub$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RemoteStub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RemoteStub$class_object;

#endif	/* _JC_java_rmi_server_RemoteStub_H_ */
